@@ -35,7 +35,8 @@
 #include "ev-window.h"
 #include "ev-utils.h"
 
-#define THUMBNAIL_WIDTH 75
+#define THUMBNAIL_WIDTH 100
+
 /* Amount of time we devote to each iteration of the idle, in microseconds */
 #define IDLE_WORK_LENGTH 5000
 
@@ -222,8 +223,9 @@ do_one_iteration (EvSidebarThumbnails *ev_sidebar_thumbnails)
 			    COLUMN_THUMBNAIL_SET, &thumbnail_set,
 			    -1);
 	if (!thumbnail_set) {
-		pixbuf = ev_document_thumbnails_get_thumbnail (EV_DOCUMENT_THUMBNAILS (priv->document),
-							       priv->current_page, THUMBNAIL_WIDTH);
+		pixbuf = ev_document_thumbnails_get_thumbnail
+				(EV_DOCUMENT_THUMBNAILS (priv->document),
+				 priv->current_page, THUMBNAIL_WIDTH, TRUE);
 
 		gtk_list_store_set (priv->list_store,
 				    &(priv->current_page_iter),
@@ -360,6 +362,8 @@ ev_sidebar_thumbnails_set_document (EvSidebarThumbnails *sidebar_thumbnails,
 					       1, THUMBNAIL_WIDTH, &width, &height);
 	loading_icon = ev_document_misc_get_thumbnail_frame (width, height, NULL);
 
+	gtk_list_store_clear (priv->list_store);
+
 	for (i = 1; i <= n_pages; i++) {
 		page = g_strdup_printf ("<i>%d</i>", i);
 		gtk_list_store_append (priv->list_store, &iter);
